# This is the forum appearance template file.
# It's evaluated as Perl, so you'll need to escape any $, %, @, | or \ characters in the strings
# with a backslash in front, but you can call other functions etc. to construct your templates.

# Basically this is a large list of "templates", into which the actual forum data is inserted
# to form the displayed output of the script. It works by having strings with many "substitutions"
# like [!NAMEHERE!] in them, which is where the forum information is inserted. The basic format is:

# $forum_template{'templateNameHere'} = qq|
# <content>content content [!SUBSTITUTION!] content</content>
# |;

# Some of the advanced substitutions have multiple options. The format for them is:
#   [?SUBSTITUTION^string1^string2?]
# These are used as if/else substitutions, for example highlighting popular topics, when
# string1 is inserted if the forum/topic is popular and string2 if it is not.


# Substitutions that are commonly available in most templates are:
#
# [!HOMEURL!] the address of the forum index page, available everywhere.
# [!NEWTOPICURL!] the address of the "Create New Topic" page for the forum.
# [!FORUMNAME!], [!FORUMTEXT!], [!FORUMURL!] which describe the selected forum.
# [!TOPICNAME!] and [!TOPICURL!] are available when a topic is selected.
#
# [?ISLOGGEDIN^abc^xyz?] will insert "abc" if a user is logged in, otherwise "xyz".
# [!LOGINURL!] is the address to which a login <form> should be submitted.
# [!LOGINFIELDS!] must be included inside a login <form> tag.
# [!USERURL!] [!ACCOUNTURL!] are the addresses of the user's account info & settings.
# [!USERNAME!] is the name of the currently logged-in user.
# [!LOGOUTURL!] is the URL that will logout a currently-logged-in user.
#
# For speed reasons, the "row" templates do not have all of these available
# (e.g. you aren't able to insert a login form in the middle of search results).
# If that really bothers you, edit the script source ;).

# Also important are the page-listing functions used in many templates. They are:
#   [?HASPAGES^string1^string2?] which inserts "string1" into the output if the appropriate
# forum or topic has multiple pages, or inserts "string2" otherwise.
#   [?PAGELIST^link format^separator1^separator2?] will write out a list of links to pages, with
# "separator1" used to separate adjacent page numbers, and "separator2" between non-adjacent pages.
#   [?PREVPAGE^link format^otherwise?] and NEXTPAGE will write a link to the appropriate pages
# if possible, otherwise will write their "otherwise" string if this is the first/last page.
# All these may include [!PAGEURL!] and [!PAGENUM!] to construct links, see the examples below.

# If none of that made sense, run the script and compare the "View Source" output to this file.
# You may not even need to alter the default template much, just edit the .CSS file.





# Here are some configuration directives you can tweak.
# Most text control is done via the CSS file included in the page header, below.

$forum_prefs{'topics_per_page'} = 20;
$forum_prefs{'posts_per_page'} = 15;

# Highlight forums that have had a post within the last X hours and topics with X or more posts.
$forum_prefs{'highlight_forums'} = 36;
$forum_prefs{'highlight_topics'} = 10;





# Header displayed at the top of all pages. I'm including some common JS functions inline
# (you may wish to use a JS file) that are used by later templates, and I've included
# a stylesheet (STYLE.CSS) used to format the forum text, links and forms.
# I've set the charset as ISO-8859-1 (Latin-1), you may wish to use another or UTF-8 should
# work, if you do use another charset you may need to edit the forum.pl "trimHTML()" function.
# Also, I'm including the login/logout templates in the header (if you want, you can shift
# them to the "footer" template, or just leave as-is).
# Special substitutions: [!PAGETITLE!]

$forum_template{'globalHeader'} = qq|
<!DOCTYPE html>
<html>
<head>
 <meta http-equiv="Content-type" content="text/html; charset=iso-8859-1" />
 <meta name="viewport" content="width=device-width" />
 <title>[!PAGETITLE!] - TwinHelix Forums</title>
 <link rel="stylesheet" href="/forum.css" type="text/css" media="all" />
<script type="text/javascript"><!--
function dwTime(s)
{
 var d=new Date(s*1000),months=['Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec'];
 var h=d.getHours(),m=d.getMinutes(),ap=(h<12?' AM':' PM');
 h=h?(h>12?h-12:h):12;
 if (m<10) m='0'+m;
 if (s) document.write(h+':'+m+ap+', '+d.getDate()+' '+months[d.getMonth()]+' '+d.getFullYear());
}
//--></script>
</head>

<body>


<div id="loginbar">
 <div id="sitelinks"><a name="top"></a><a href="/">TwinHelix Designs</a></div>
[?ISLOGGEDIN^
 Logged in as <strong><a href="[!USERURL!]">[!USERNAME!]</a></strong>
 - <a href="[!ACCOUNTURL!]">Edit Account</a> - <a href="[!LOGOUTURL!]">Logout</a>
^
<form method="post" action="[!LOGINURL!]">
 <div>
  <label>User: <input type="text" name="user" class="textbox" alt="Username" /></label>
  <label>Pass: <input type="password" name="pass" class="textbox" alt="Password" /></label>
[!LOGINFIELDS!]
  <input type="submit" value="Login" class="button" />
  -
  <a href="[!ACCOUNTURL!]" title="Click here to signup">Create Account</a>
 </div>
</form>
?]
</div>
|;




# Footer displayed at the bottom of every page. Please leave this crediting link intact;
# either that, or if you want to make a donation for usage of the script, I'm sure I could
# waive this requirement!

$forum_template{'globalFooter'} = qq|

<div class="footer">
 <div>
  Powered by <a href="http://www.twinhelix.com/"
   title="Download the script behind these forums..."
   onmouseover="if (this.getAttribute) return status=this.getAttribute('title')"
   onmouseout="status=''">TwinHelix Forums v1.0 Beta 2</a>.
 </div>
</div>


</body>
</html>
|;














# Top of "Forum List" page. Have a welcome message here, and set up any table headers or similar
# you'll use to display the forum results later on.

$forum_template{'listForumsTop'} = qq|

<h1>Welcome to TwinHelix Forums!</h1>

<p>The script should now be running OK. Edit TEMPLATE.PL to change this.</p>

<table class="forumlist">

 <tr>
  <th>Forum Name</th>
  <th>Last Post</th>
  <th>Topics</th>
  <th>Posts</th>
 </tr>
|;





# This is the format used for a "section break" row in the forum listing.
# Special substitution: [!SECTIONTITLE!]

$forum_template{'listForumsSection'} = qq|
 <tr>
  <td class="sectionbreak" colspan="4">[!SECTIONTITLE!]</td>
 </tr>
|;





# One row of information for a forum. Note that I'm calling the JavaScript time display function
# in the header: the LASTTIMESECS substitution records the raw number of seconds since 1970,
# suitable for feeding to a script that outputs the result in the client's local timezone.
# Alternatively, LASTTIMEGMT is a nicely formatted datestamp in Greenwich Mean Time.
# Also, the HIGHLIGHTED substitution is special, you include two strings separated by hashes,
# the first of which is written if the forum has ben updated in the last few hours, and the latter
# if it is slightly older. This is used to bold recent forums, you may want to include small
# "folder-on-fire" icon images for recently updated forums etc.
# Special substitutions: [!LASTTIMESECS!], [!LASTTIMEGMT!], [!LASTAUTHOR!], 
# [?HIGHLIGHTED^...^...?], [!TOPICS!], [!POSTS!].

$forum_template{'listForumsRow'} = qq|
 <tr class="[!ROWNORMCLASS!]" onclick="location.href='[!FORUMURL!]'">
  <td class="forumname">
   <a href="[!FORUMURL!]">[!FORUMNAME!]</a>
   <div>[!FORUMTEXT!]</div>
  </td>
  <td class="[?HIGHLIGHTED^lastpostnew^lastpost?]">
   <script type="text/javascript"><!--
    dwTime([!LASTTIMESECS!]);
   //--></script>
   <noscript><div>[!LASTTIMEGMT!]</div></noscript>
   <div>[!LASTAUTHOR!]</div>
  </td>
  <td class="topics">[!TOPICS!]</td>
  <td class="posts">[!POSTS!]</td>
 </tr>
|;




# The bottom of the forum list page.
# Special substitutions: [!TOTALTOPICS!], [!TOTALPOSTS!]

$forum_template{'listForumsBottom'} = qq|
 <tr class="forumlistfooter">
  <td colspan="2">Totals:</td>
  <td class="topics">[!TOTALTOPICS!]</td>
  <td class="posts">[!TOTALPOSTS!]</td>
 </tr>

</table>

|;














# This "listTopics" template is dual-function: it displays regular topic lists and also
# search results for a forum. Special substitutions:
# [!ISSEARCH^...^...?] can be used to tell is this is a seach result or not.
# [!SEARCHURL!] is the URL to which the a search form should be submitted.
# [!SEARCHFIELDS!] is hidden information that must be included in a search form.
# [!SEARCHKEYWORDS!] are the keywords searched for, if any.
# [?HASPAGES^...^...?], [?PAGELIST^...^...^...?], [?PREVPAGE^...^...?], [?NEXTPAGE^...^...?]

$forum_template{'listTopicsTop'} = qq|
<h1>[!FORUMNAME!]</h1>

<form class="navfloat" id="searchform" action="[!SEARCHURL!]" method="post"
 onsubmit="if (!this.keywords.value){ alert('Please enter some search keywords'); return false }">
 <div>
  [!SEARCHFIELDS!]
  <input class="textbox" type="text" name="keywords" maxlength="100"
   alt="Enter the keywords for which you want to search here"
   value="[?ISSEARCH^[!SEARCHKEYWORDS!]^Enter keywords...?]"
   onfocus="var e = document.forms.searchform.elements;
    if (e.keywords.value == 'Enter keywords...') e.keywords.value = ''" />
  <input class="button" type="submit" value="Search" />
 </div>
</form>

<div class="whereami">
 <a href="[!HOMEURL!]">Forums</a> &gt;
 <a href="[!FORUMURL!]">[!FORUMNAME!]</a> &gt;
 [?ISSEARCH^Search Results: &quot;[!SEARCHKEYWORDS!]&quot;^Page [!PAGENUM!]?]
</div>

[?HASPAGES^<div class="pagediv">
 Pages: <span class="pagelist">^?]
 [?PREVPAGE^<a href="[!PAGEURL!]">&lt; &lt; Previous </a> -^?]
 [?PAGELIST^<a href="[!PAGEURL!]"> [!PAGENUM!] </a>^,^...?]
 [?NEXTPAGE^- <a href="[!PAGEURL!]"> Next &gt; &gt;</a>^?]
 [?HASPAGES^</span>
</div>^?]

<table class="topiclist">

 <tr>
  <th>Started By</th>
  <th>Topic&nbsp; &nbsp;<a href="[!NEWTOPICURL!]">[ Create New Topic ]</a></th>
  <th>Posts</th>
  <th colspan="2">Last Post</th>
 </tr>
|;




# Empty forum row --  this is written if there are no topics in the forum, or no search results.

$forum_template{'listTopicsError'} = qq|
 <tr>
  <td colspan="5" id="listtopicerror">No topics found.</td>
 </tr>
|;




# Otherwise, write out a row for each topic. Again, we have a special HIGHLIGHTED substitution
# that has two strings in it, the first for topics with more posts than the threshold and the
# second otherwise. There are also special topic "pinned" and "locked" states you can detect, I'm
# labelling rows and also giving pinned rows a different CSS class.
# We also have the page-list substitutions, for multi-page topics. Special substitutions:
# [!TOPICURL!], [!TOPICNAME!], [!ORIGAUTHOR!], [!ORIGTIMESECS!],
# [!ORIGTIMEGMT!], [!LASTAUTHOR!], [!LASTTIMESECS!], [!LASTTIMEGMT!], [!POSTS!],
# [?HIGHLIGHTED^...^...?], [?PINNED^...^...?], [?LOCKED^...^...?],
# [?HASPAGES^...^...?], [?PAGELIST^...^...^...?]


$forum_template{'listTopicsRow'} = qq|
 <tr [?PINNED^class="pinned"^?] onclick="location.href='[!TOPICURL!]'">
  <td class="origauthor">[!ORIGAUTHOR!]</td>
  <td>
   [?PINNED^<strong title="This topic has been pinned to the top of this forum">Pinned:</strong>^?]
   [?LOCKED^<strong title="This topic is not accepting new posts from users">Locked:</strong>^?]
   <a href="[!TOPICURL!]">[!TOPICNAME!]</a> [?HASPAGES^ - page: <span class="pagelist">^?]
   [?PAGELIST^<a href="[!PAGEURL!]"> [!PAGENUM!] </a>^,^...?][?HASPAGES^</span>^?]
  </td>
  <td class="[?HIGHLIGHTED^postspopular^posts?]">[!POSTS!]</td>
  <td class="lastpost">
   <div class="lastauthor">[!LASTAUTHOR!]</div>
   <script type="text/javascript"><!--
    dwTime([!LASTTIMESECS!]);
   //--></script>
   <noscript><div>[!LASTTIMEGMT!]</div></noscript>
  </td>
 </tr>
|;




# Similar substitutions available as the topic list top template.

$forum_template{'listTopicsBottom'} = qq|
</table>

[?HASPAGES^<div class="pagediv">
 Pages: <span class="pagelist">^?]
 [?PREVPAGE^<a href="[!PAGEURL!]">&lt; &lt; Previous </a> -^?]
 [?PAGELIST^<a href="[!PAGEURL!]"> [!PAGENUM!] </a>^,^...?]
 [?NEXTPAGE^- <a href="[!PAGEURL!]"> Next &gt; &gt;</a>^?]
 [?HASPAGES^</span>
</div>^?]

|;








# The top of the "Create New Topic" page. It is followed by the message posting form.

$forum_template{'newTopicTop'} = qq|
<h1>Create New Topic</h1>

<div class="whereami">
 <a href="[!HOMEURL!]">Forums</a> &gt;
 <a href="[!FORUMURL!]">[!FORUMNAME!]</a> &gt;
 Create New Topic
</div>

<p>Here you can create a new topic to display within this forum.</p>

<p>Before creating a new topic, please <strong>browse through some existing topics</strong>, as there's
no use in duplicating discussions already under way, or try <strong>searching for keywords</strong>
related to the topic.</p>

<p>Otherwise, fill in the form to post a message under a new topic:</p>
|;




# The Message Posting form, used to post replies or create new topics.
# POSTFIELDS must be included somewhere (a couple of hidden input tags).
# ISNEWTOPIC is a conditional test that detects if this is a new topic or not.
# Likewise ISNEWPOST will be false for users or admins re-editing an existing post.
# Some other things: anonymous posters must supply an additional "author" input field,
# and if posting fails, this form will be returned again along with an error message.
# Special substitutions: [!POSTURL!], [!POSTFIELDS!], [?ISNEWTOPIC^...^...?],
# [?ISNEWPOST^...^...?], [!TOPICNAME!], [!AUTHOR!], [!MESSAGE!]

my $max_len = $forum_prefs{'max_post_len'} || '';
$forum_template{'postForm'} = qq|

[?ISNEWPOST^<h2>Post a Reply:</h2>^?]

<form class="postform" action="[!POSTURL!]" method="post"
 onsubmit="with (this) if (this.author &amp;&amp; !author.value \|\|
  this.topicname &amp;&amp; !topicname.value \|\| !this.n &amp;&amp; !message.value)
   { alert('Please fill in the form fields before posting your message.'); return false }">
<div>
[!POSTFIELDS!]
[?ISLOGGEDIN^^
 <p>
  You are not logged in, and will be posting anonymously as a guest.
  If you want to post using an account, please login at the top of this page.
 </p>

 <label for="author">Your Name:</label>
 <input class="textbox" type="text" name="author" id="author" maxlength="25"
  value="[!AUTHOR!]" />
?]
[?ISNEWTOPIC^
 <label for="topicname">Topic Name:</label>
 <input class="textbox" type="text" name="topicname" id="topicname" maxlength="60"
  value="[!TOPICNAME!]" />
^?]
 <label for="message">Message:</label>
 <textarea class="textbox" name="message" id="message">[!MESSAGE!]</textarea>

 <ul>
  <li>HTML will be converted to visible &amp;gt; and &amp;lt; symbols.</li>
  <li>Maximum message length is $max_len characters.</li>
  <li>URL posting: <strong>[url]http://www.twinhelix.com</strong></li>
  <li>Image posting: <strong>[img]http://mysite.com/pic.gif</strong></li>
 </ul>

 <input type="reset" value="Reset Form" class="button"
  onclick="return confirm('Do you really want to erase this form?')" />
 <input type="submit" value="Submit Post" class="button" />

</div>
</form>
|;




# The "Post Error" display, if the script cannot post the user's message (too long, missed
# necessary information, etc. etc.). This is written to the document and followed by the
# posting form in the template above. Special substitutions: [!ERRORMESSAGE!].

$forum_template{'postError'} = qq|
<h1>Post Error!</h1>

<div class="whereami">
 <a href="[!HOMEURL!]">Forums</a> &gt;
 <a href="[!FORUMURL!]">[!FORUMNAME!]</a> &gt;
 Post Error
</div>

<div class="posterror">
[!ERRORMESSAGE!]
</div>
|;















# This forms the top of the post-display pages. Special substitutions:
# [!HOMEURL!], [!FORUMURL!], [!FORUMNAME!], [!FORUMTEXT!], [!TOPICURL!],
# [?HASPAGES^...^...?], [?PAGELIST^...^...^...?], [?PREVPAGE^...^...?], [?NEXTPAGE^...^...?]

$forum_template{'displayTopicTop'} = qq|
<h1>[!TOPICNAME!]</h1>

<div class="navfloat"><a href="#bottom">Go to Bottom</a></div>

<div class="whereami">
 <a href="[!HOMEURL!]">Forums</a> &gt;
 <a href="[!FORUMURL!]">[!FORUMNAME!]</a> &gt;
 [!TOPICNAME!] [?HASPAGES^&gt; Page [!PAGENUM!]^?]
</div>

[?HASPAGES^<div class="pagediv">
 Pages: <span class="pagelist">^?]
 [?PREVPAGE^<a href="[!PAGEURL!]">&lt; &lt; Previous </a> -^?]
 [?PAGELIST^<a href="[!PAGEURL!]"> [!PAGENUM!] </a>^,^...?]
 [?NEXTPAGE^- <a href="[!PAGEURL!]"> Next &gt; &gt;</a>^?]
 [?HASPAGES^</span>
</div>^?]

<div class="headerpost">
 <div class="postinfo">Author</div>
 <div class="postcontent">Message</div>
</div>

|;



# This formats each row in the post display, containing time/author/message/etc.
# Special substitutions:
# [?ISUSER^...^...?] tests if this post is by a logged-in user, or a guest.
# [?USERSIG^...^...?] tests if the post author account has a signature.
# [?ISEDITABLE^...^...?] tests if the current user has rights to edit/delete this post.
# [!EDITURL!] is the URL to the post editing page if applicable.
# [!GROUP!], [!POSTS!], [!JOINED!], [!LOCATION!] and [!SIG!] insert user information.
# [!NUM!], [!AUTHOR!], [!TIMESECS!], [!TIMEGMT!], [!IPADDR!], [!MESSAGE!]

$forum_template{'displayTopicRow'} = qq|

<div class="hide"><hr /></div>

<div class="post">
 <div class="postinfo">
  [!NUM!]) <span class="author">[!AUTHOR!]</span>
  <span class="inforow">Group: [!GROUP!]</span>
  <br />
  [?ISUSER^<span class="inforow">Posts: [!POSTS!]</span>
  <span class="inforow">Joined: [!JOINED!]</span>
  <span class="inforow">Location: [!LOCATION!]</span>
  ^?]
  <span class="inforow">IP: [!IPADDR!]</span>
 </div>
 <div class="postcontent">
  <div class="postdate">
   [?ISEDITABLE^(<a href="[!EDITURL!]">Edit</a>) ^?]
   Posted: <script type="text/javascript"><!--
    dwTime([!TIMESECS!]);
   //--></script>
   <noscript><div>[!TIMEGMT!]</div></noscript>
  </div>
  <div class="message">
   [!MESSAGE!]
  [?USERSIG^<div class="sig">[!SIG!]</div>^?]
  </div>
  <div class="postend"></div>
 </div>
 <div class="postend"></div>
</div>
|;



# The bottom of the post listing. Same substitutions available as the top of the listing.

$forum_template{'displayTopicBottom'} = qq|

[?HASPAGES^<div class="pagediv">
 Pages: <span class="pagelist">^?]
 [?PREVPAGE^<a href="[!PAGEURL!]">&lt; &lt; Previous </a> -^?]
 [?PAGELIST^<a href="[!PAGEURL!]"> [!PAGENUM!] </a>^,^...?]
 [?NEXTPAGE^- <a href="[!PAGEURL!]"> Next &gt; &gt;</a>^?]
 [?HASPAGES^</span>
</div>^?]

<div class="navfloat"><a name="bottom"></a><a href="#top">Back to Top</a></div>
|;



# The error template, if the topic information cannot be found.

$forum_template{'displayTopicError'} = qq|
<h1>Topic display error</h1>
<p><strong>ERROR: Topic information not found.</strong><p>
<p>The data associated with this topic number cannot be located in the forum system.<p>
<p>It may have recently been deleted, or you may have typed in an incorrect URL to locate it.</p>
<p>Please return to the <a href="[!FORUMURL!]">topic listing</a> to reselect a topic.</p>
|;



# This is shown in locked topics, or topics in which the user isn't allowed to post, in place
# of the "Post A Reply" form.
$forum_template{'displayTopicNoPost'} = qq|
 <p>Sorry, this topic is not accepting new posts.</p>
|;










# The template for editing or deleting posts. This is followed by the posting form.

$forum_template{'editPost'} = qq|
<h1>Edit Post</h1>

<div class="whereami">
 <a href="[!HOMEURL!]">Forums</a> &gt;
 <a href="[!FORUMURL!]">[!FORUMNAME!]</a> &gt;
 <a href="[!TOPICURL!]">[!TOPICNAME!]</a> &gt;
 Edit Post
</div>

<p>Please type in your amended message, or delete it all to remove the post entirely.</p>

|;



# The topic locking/deleting template, this is shown after the post form.
# It consists of a form that must contain [!HIDDENFIELDS!] and post back to the topic URL.
# The PINNED and LOCKED substitutions are available to show the current topic state.

$forum_template{'topicSettings'} = qq|
<h2>Topic Settings</h2>

<form action="[!TOPICURL!]" method="post" id="topicsettings">
 <div>
[!HIDDENFIELDS!]
  <label for="topicname">Topic Name:</label>
  <input class="textbox" type="text" name="topicname" id="topicname" size="80" maxlength="60"
   value="[!TOPICNAME!]" />
 </div>
 <div>
  <input type="checkbox" name="locked" id="locked" [?LOCKED^checked="checked"^?] />
   <label for="locked" title="Stop this topic accepted new posts">Locked</label>
  <input type="checkbox" name="pinned" id="pinned" [?PINNED^checked="checked"^?] />
   <label for="pinned" title="Pin this topic to the top of its forum">Pinned</label>
  <input type="checkbox" name="delete" id="delete" />
   <label for="delete" title="Deletes the topic and all posts within">Delete Topic</label>
  <input type="submit" class="button" value="Change Settings" />
 </div>
</form>

|;










# The login error page, displayed if a user inputs an incorrect username/password.

$forum_template{'userLoginError'} = qq|
<h1>Login Error</h1>

<p>The username and password you provided are incorrect.</p>
<p>Make sure you have correctly capitalised and spelt both!</p>
<p>Please try again, or press "Back" to return to the previous page.</p>
</p>
|;


# The account editing / signup page. I use one template for both, with some alterations depending
# on whether the user is currently logged in or not. This uses ?ISLOGGEDIN? extensively to switch
# between modes, as logged-out users can never edit their own account. Special substitutions:
# [!ACCOUNTUSER!] is (surprisingly) the account username being edited, if logged in.
# [!ACCOUNTERROR!] contains any error messages (incorrectly filled out form etc) after submittal.
# [!ACCOUNTPOSTURL!] goes in the "action" field for your form.
# [!HIDDENFIELDS!] contain post logic and antispam fields.
# [!BIO!], [!LOCATION!] and [!SIG!] are the current values returned for these fields.
# [?ACCEDIT^...^...?] is true if the current user has admin privileges, and is entitled to change
# the privilege level of this account via the [!GROUPSELECT!] select-box.

$forum_template{'userAccountEdit'} = qq|
<h1>[?ISLOGGEDIN^[!ACCOUNTUSER!]^Create Account?]</h1>

<div class="whereami">
 <a href="[!HOMEURL!]">Forums</a> &gt; Account Setup
</div>

<div class="accounterror">
[!ACCOUNTERROR!]
</div>

<form class="accountform" method="post" action="[!ACCOUNTPOSTURL!]">
<div>
 <input type="hidden" name="a" value="account" />
[?ISLOGGEDIN^
 <input type="hidden" name="user" value="[!ACCOUNTUSER!]" />
^
 <p>You don't need an account to post, but if you have one, you can edit your posts later
  and display more information with your messages.</p>

 <h3>Required Fields</h3>

 <p>Please choose a user name you want to use on these forums. Alphanumeric characters only.</p>
 <div>
  <label for="user">User Name:</label>
  <input type="text" name="user" id="user" size="25" maxlength="25" value="[!ACCOUNTUSER!]"
   class="textbox" />
 </div>
?]

[!HIDDENFIELDS!]

[?ISLOGGEDIN^
 <p>If you want to change your existing password, please enter it here, otherwise leave this
  field blank:</p>
 <div>
  <label for="oldpass">Old Password:</label>
  <input type="password" maxlength="25" name="oldpass" id="oldpass"
   class="textbox" />
 </div>
^?]
 <p>Enter your new account password here twice (they must both match)</p>
 <div>
  <label for="pass">New Password:</label>
  <input type="password" maxlength="25" name="pass" id="pass"
   class="textbox" />
 </div>
 <div>
  <label for="pass2">Re-type Password:</label>
  <input type="password" maxlength="25" name="pass2" id="pass2"
   class="textbox" />
 </div>

 [?ISLOGGEDIN^^<h3>Optional Fields</h3>?]

 <p>Where in the world are you? This gets displayed with your posts.</p>
 <div>
  <label for="location">Location:</label>
  <input type="text" name="location" id="location" maxlength="30" value="[!LOCATION!]"
   class="textbox" />
 </div>

 <p>
  Say a little about yourself, include some contact information, or just leave it blank.
  This will be displayed on your "User Info" page.
 </p>
 <div>
  <label for="bio">Bio:</label>
  <textarea name="bio" id="bio" class="textbox">[!BIO!]</textarea>
 </div>

 <p>A signature will be automatically appended to your posts (max 200 chars).</p>
 <div>
  <label for="sig">Signature:</label>
  <textarea name="sig" id="sig" class="textbox">[!SIG!]</textarea>
 </div>

[?ACCEDIT^
 <p>ADMINS ONLY: You can change the privilege type of this account.</p>
 <div>
  <label for="groupselect">User Group:</label>
  <select name="groupselect" id="groupselect">
  [!GROUPSELECT!]
  </select>
 </div>
^?]
[?ISLOGGEDIN^^
 <p>
  You can change all these account settings later, except for the username.
  Plus, you must have cookies enabled in your browser to login.
 </p>
?]

 <div>
  <input class="button" type="submit" value="[?ISLOGGEDIN^Save Changes^Create Account?]" />
 </div>

</div>

</form>
|;




# The account information display template. Basically it's identical to the one above, but doesn't
# have any editable components. This is used to display other people's profiles.

$forum_template{'userAccountView'} = qq|
<h1>[!ACCOUNTUSER!]</h1>

[?ACCEDIT^<div class="navfloat"><a href="[!THISACCOUNTURL!]">Edit account</a></div>^?]

<div class="whereami">
 <a href="[!HOMEURL!]">Forums</a> &gt; User Information
</div>

<p><strong>Bio:</strong></p>
<div>
 [!BIO!]
</div>

<p><strong>Posts:</strong> [!POSTS!]</p>

<p><strong>Joined:</strong> [!JOINED!]</p>

<p><strong>Location:</strong> [!LOCATION!]</p>

<p><strong>Sig:</strong></p>
<div>
 [!SIG!]
</div>

|;



# The 'not allowed' template, encountered in that rare situation when a visito tries to pull off
# a stunt they're not entitled to do. [!ACTION!] tells them what went wrong.
$forum_template{'userDisallowed'} = qq|
<h1>Sorry!</h1>

<div class="whereami">
 <a href="[!HOMEURL!]">Forums</a> &gt; Error
</div>

<p>You're currently not allowed to:</p>
<p><strong>[!ACTION!]</strong></p>
<p>Please login with the appropriate account.</p>
|;
